# Copyright(c) 2011-2012 Association of Universities for Research in Astronomy, Inc.

# The Gemini IRAF package requires a number of other external IRAF packages. 
# The Gemini IRAF package will not load if any of these packages are
# missing. This script checks if external package versions are installed and up
# to date.
#
# To use this task to check a Gemini IRAF installation, define and execute the
# task by typing the following at the IRAF or PyRAF prompt:
#
#     ecl> task $install_check=/iraf/extern/gemini/install_check.cl
#     ecl> install_check
#
# If the Gemini IRAF package is installed in a non-standard location (i.e.,
# somewhere other than /iraf/extern/gemini/), be sure to update the path to the
# task in the task definition above.  

procedure install_check

begin

    struct l_check
    bool   isiraf215plus
    string pkg_path

    show iraf | tee ("extern_check.log", out_type="text", append+)
    show IRAFARCH | tee ("extern_check.log", out_type="text", append+)
    show version | tee ("extern_check.log", out_type="text", append+)
    show gemini | tee ("extern_check.log", out_type="text", append+)
    show extern | tee ("extern_check.log", out_type="text", append+)

    # Check IRAF. The Gemini IRAF package requires IRAF v2.14.1.

    show version | scan (line)
    i = stridx ("V", line)
    j = stridx ("-", line)
    s1 = substr (line, i+1, j-1)
    s2 = substr (line, i+1, strlen(line))
    l_check = ""
    show IRAFARCH | scan (line)
    isiraf215plus = no
    if (s2 == "2.14.1") {
        # Make sure the critical patch is installed
        dir ("iraf$bin."//line//"/x_tv.e", long+, ncols=0,\
            maxch=18, sort+, all-) | match ("Jan") | scan (l_check)
        dir ("iraf$bin."//line//"/x_tv.e", long+, ncols=0,\
            maxch=18, sort+, all-) | match ("Aug") | scan (l_check)
        dir ("iraf$bin."//line//"/x_tv.e", long+, ncols=0,\
            maxch=18, sort+, all-) | match ("Sep") | scan (l_check)
        if (l_check == "") {
            print ("Installation of IRAF 2.14.1 patch has \
                not been installed. FAIL") |\
                tee ("extern_check.log", out_type="text", append+)
            dir ("iraf$bin."//line//"/x_tv.e", long+, ncols=0,\
                maxch=18, sort+, all-) | \
                tee ("extern_check.log", out_type="text", append+) 
        } else {
            print ("IRAF installation 2.14.1 with patch is up to date. \
                PASS") | tee ("extern_check.log", out_type="text", append+)
        }
    } else if (substr(s2,1,4) == "2.15") {
        # iraf 2.15 onwards
        isiraf215plus = yes
        if (s2 == "2.15.1a") {
            print ("IRAF installation 2.15.1a is up to date. PASS") |\
            tee ("extern_check.log", out_type="text", append+)
        } else {
            print ("IRAF v2.15.1a is required. FAIL")  |\
            tee ("extern_check.log", out_type="text", append+)
        }
    } else {
        # IRAF version is neither 2.14.1 or 2.15.1a
        print ("IRAF older than v2.14.1.  Please install v2.14.1 or \
            greater.  FAIL")
    }

    # Check to see if the external packages that are required by the Gemini
    # IRAF package are installed

    delete ("extern_check.log", verify-, >& "dev$null")
    # Check stsdas
    if (access("stsdas$stsdas.par")) {
        if (stsdas.version == "V3.14") 
            print ("stsdas v3.14 installed. PASS") |\
            tee ("extern_check.log", out_type="text", append-)
        else if (stsdas.version == "V3.13") 
            print ("stsdas v3.13 installed. PASS") |\
            tee ("extern_check.log", out_type="text", append-)
        else {
            print ("STSDAS version: "//stsdas.version) |\
            tee ("extern_check.log", out_type="text", append-)
            print ("stsdas less than v3.13. Need to update. FAIL") |\
            tee ("extern_check.log", out_type="text", append+)
        }
    } else
        print ("stsdas not correctly installed! FAIL") |\
        tee ("extern_check.log", out_type="text", append-)

    # Check tables 
    if (access("tables$tables.par")) {
        if (tables.version == "V3.14")
            print ("tables v3.14 installed. PASS") |\
            tee ("extern_check.log", out_type="text", append+)
        else if (tables.version == "V3.13")
            print ("tables v3.13 installed. PASS") |\
            tee ("extern_check.log", out_type="text", append+)
        else  {
            print ("TABLES version: "//tables.version) |\
            tee ("extern_check.log", out_type="text", append+)
            print ("tables less than v3.13. Need to update. FAIL") |\
            tee ("extern_check.log", out_type="text", append+)
        }
    } else 
        print ("tables not correctly installed! FAIL") |\
        tee ("extern_check.log", out_type="text", append+)
    
    # Set the correct path according to iraf version for fitsutil check
    if (isiraf215plus) {
        pkg_path = "src"
    } else {
        pkg_path = "pkg"
    }

    # Check fitsutil (lpar fitsutil; version = "30May1995")
    if (access("fitsutil$fitsutil.par")) {
        l_check = ""
        dir ("fitsutil$"//pkg_path//"/getcmd.x", long+, ncols=0, maxch=18, \
            sort+, all-)| match 'Aug 26  2005' | scan (l_check)
        if (l_check != "")
            print ("fitsutil package up to date. PASS") |\
            tee ("extern_check.log", out_type="text", append+)
        else {
            dir ("fitsutil$"//pkg_path//"/fxinsert.x", long+, ncols=0, \
                maxch=18, sort+, all-) | match 'Mar 30  2005' | scan (l_check)
            if (l_check != "")
                print ("fitsutil package v.Mar 30 2005. Consider upgrading. \
                PASS.") | tee ("extern_check.log", out_type="text", append+)
            else {
                dir ("fitsutil$"//pkg_path//"/nhedit.x", long+, ncols=0, \
                    maxch=18, sort+, all-) | match 'Mar 11  2005' | \
                    scan (l_check)
                if (l_check != "")
                    print ("fitsutil package v.Mar 11 2005. Consider \
                    upgrading. PASS.") | tee ("extern_check.log", 
                    out_type="text", append+)
                else
                    dir ("fitsutil$"//pkg_path//"/getcmd.x", long+, ncols=0, \
                        maxch=18, sort+, all-)
                    print ("fitsutil package not up to date. FAIL.") |\
                    tee ("extern_check.log", out_type="text", append+)
            }
        }
    } else
        print ("fitsutil not correctly installed! FAIL") |\
        tee ("extern_check.log", out_type="text", append+)

    # Check gmisc (lpar gmisc; version = "Jan00")
    if (access("gmisc$gmisc.par")) {
        l_check = ""
        dir ("gmisc", long+, ncols=0, maxch=18, sort+, all-) |\
            match 'Apr 14  2004' | scan (l_check)
        if (l_check == "") 
            print ("gmisc package not up to date. FAIL") |\
            tee ("extern_check.log", out_type="text", append+)
        else 
            print ("gmisc up to date. PASS") |\
            tee ("extern_check.log", out_type="text", append+)
    } else
        print ("gmisc not correctly installed! FAIL") |\
        tee ("extern_check.log", out_type="text", append+)

    # Check gemini
    if (access("gemini$gemini.par")) {
        if (gemini.verno == "v1.11")
            print ("gemini v1.11 installed. PASS") |\
            tee ("extern_check.log", out_type="text", append+)
        else if (gemini.verno == "v1.11.1beta")
            print ("gemini v1.11.1beta installed. PASS") |\
            tee ("extern_check.log", out_type="text", append+)
        else {
            print ("gemini version: "//gemini.verno) |\
            tee ("extern_check.log", out_type="text", append+)
            print ("gemini package less than v1.11. Need to update. FAIL") |\
            tee ("extern_check.log", out_type="text", append+)
        }
    } else
        print ("gemini not correctly installed! FAIL") |\
        tee ("extern_check.log", out_type="text", append+)

    # Check machine name
    !uname -a | tee -a extern_check.log

end
